# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_core_specializations_inner import (
    V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_end_time import (
    V0041OpenapiReservationRespReservationsInnerEndTime,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_purge_completed import (
    V0041OpenapiReservationRespReservationsInnerPurgeCompleted,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_start_time import (
    V0041OpenapiReservationRespReservationsInnerStartTime,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_watts import (
    V0041OpenapiReservationRespReservationsInnerWatts,
)


class V0041OpenapiReservationRespReservationsInner(BaseModel):
    """
    V0041OpenapiReservationRespReservationsInner
    """  # noqa: E501

    accounts: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of permitted accounts"
    )
    burst_buffer: Optional[StrictStr] = Field(default=None, description="BurstBuffer")
    core_count: Optional[StrictInt] = Field(default=None, description="CoreCnt")
    core_specializations: Optional[
        List[V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner]
    ] = Field(default=None, description="Reserved cores specification")
    end_time: Optional[V0041OpenapiReservationRespReservationsInnerEndTime] = None
    features: Optional[StrictStr] = Field(default=None, description="Features")
    flags: Optional[List[StrictStr]] = Field(
        default=None, description="Flags associated with the reservation"
    )
    groups: Optional[StrictStr] = Field(default=None, description="Groups")
    licenses: Optional[StrictStr] = Field(default=None, description="Licenses")
    max_start_delay: Optional[StrictInt] = Field(
        default=None, description="MaxStartDelay in seconds"
    )
    name: Optional[StrictStr] = Field(default=None, description="ReservationName")
    node_count: Optional[StrictInt] = Field(default=None, description="NodeCnt")
    node_list: Optional[StrictStr] = Field(default=None, description="Nodes")
    partition: Optional[StrictStr] = Field(default=None, description="PartitionName")
    purge_completed: Optional[
        V0041OpenapiReservationRespReservationsInnerPurgeCompleted
    ] = None
    start_time: Optional[V0041OpenapiReservationRespReservationsInnerStartTime] = None
    watts: Optional[V0041OpenapiReservationRespReservationsInnerWatts] = None
    tres: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of required TRES"
    )
    users: Optional[StrictStr] = Field(
        default=None, description="Comma separated list of permitted users"
    )
    __properties: ClassVar[List[str]] = [
        "accounts",
        "burst_buffer",
        "core_count",
        "core_specializations",
        "end_time",
        "features",
        "flags",
        "groups",
        "licenses",
        "max_start_delay",
        "name",
        "node_count",
        "node_list",
        "partition",
        "purge_completed",
        "start_time",
        "watts",
        "tres",
        "users",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "MAINT",
                    "NO_MAINT",
                    "DAILY",
                    "NO_DAILY",
                    "WEEKLY",
                    "NO_WEEKLY",
                    "IGNORE_JOBS",
                    "NO_IGNORE_JOBS",
                    "ANY_NODES",
                    "STATIC",
                    "NO_STATIC",
                    "PART_NODES",
                    "NO_PART_NODES",
                    "OVERLAP",
                    "SPEC_NODES",
                    "TIME_FLOAT",
                    "REPLACE",
                    "ALL_NODES",
                    "PURGE_COMP",
                    "WEEKDAY",
                    "NO_WEEKDAY",
                    "WEEKEND",
                    "NO_WEEKEND",
                    "FLEX",
                    "NO_FLEX",
                    "DURATION_PLUS",
                    "DURATION_MINUS",
                    "NO_HOLD_JOBS_AFTER_END",
                    "NO_PURGE_COMP",
                    "MAGNETIC",
                    "SKIP",
                    "HOURLY",
                    "NO_HOURLY",
                    "USER_DELETE",
                    "NO_USER_DELETE",
                    "REOCCURRING",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('MAINT', 'NO_MAINT', 'DAILY', 'NO_DAILY', 'WEEKLY', 'NO_WEEKLY', 'IGNORE_JOBS', 'NO_IGNORE_JOBS', 'ANY_NODES', 'STATIC', 'NO_STATIC', 'PART_NODES', 'NO_PART_NODES', 'OVERLAP', 'SPEC_NODES', 'TIME_FLOAT', 'REPLACE', 'ALL_NODES', 'PURGE_COMP', 'WEEKDAY', 'NO_WEEKDAY', 'WEEKEND', 'NO_WEEKEND', 'FLEX', 'NO_FLEX', 'DURATION_PLUS', 'DURATION_MINUS', 'NO_HOLD_JOBS_AFTER_END', 'NO_PURGE_COMP', 'MAGNETIC', 'SKIP', 'HOURLY', 'NO_HOURLY', 'USER_DELETE', 'NO_USER_DELETE', 'REOCCURRING')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiReservationRespReservationsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in core_specializations (list)
        _items = []
        if self.core_specializations:
            for _item_core_specializations in self.core_specializations:
                if _item_core_specializations:
                    _items.append(_item_core_specializations.to_dict())
            _dict["core_specializations"] = _items
        # override the default output from pydantic by calling `to_dict()` of end_time
        if self.end_time:
            _dict["end_time"] = self.end_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of purge_completed
        if self.purge_completed:
            _dict["purge_completed"] = self.purge_completed.to_dict()
        # override the default output from pydantic by calling `to_dict()` of start_time
        if self.start_time:
            _dict["start_time"] = self.start_time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of watts
        if self.watts:
            _dict["watts"] = self.watts.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiReservationRespReservationsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accounts": obj.get("accounts"),
                "burst_buffer": obj.get("burst_buffer"),
                "core_count": obj.get("core_count"),
                "core_specializations": [
                    V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner.from_dict(
                        _item
                    )
                    for _item in obj["core_specializations"]
                ]
                if obj.get("core_specializations") is not None
                else None,
                "end_time": V0041OpenapiReservationRespReservationsInnerEndTime.from_dict(
                    obj["end_time"]
                )
                if obj.get("end_time") is not None
                else None,
                "features": obj.get("features"),
                "flags": obj.get("flags"),
                "groups": obj.get("groups"),
                "licenses": obj.get("licenses"),
                "max_start_delay": obj.get("max_start_delay"),
                "name": obj.get("name"),
                "node_count": obj.get("node_count"),
                "node_list": obj.get("node_list"),
                "partition": obj.get("partition"),
                "purge_completed": V0041OpenapiReservationRespReservationsInnerPurgeCompleted.from_dict(
                    obj["purge_completed"]
                )
                if obj.get("purge_completed") is not None
                else None,
                "start_time": V0041OpenapiReservationRespReservationsInnerStartTime.from_dict(
                    obj["start_time"]
                )
                if obj.get("start_time") is not None
                else None,
                "watts": V0041OpenapiReservationRespReservationsInnerWatts.from_dict(
                    obj["watts"]
                )
                if obj.get("watts") is not None
                else None,
                "tres": obj.get("tres"),
                "users": obj.get("users"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode,
)


class TestV0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode:
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode`
        """
        model = V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(
                status = [
                    'INVALID'
                    ],
                return_code = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code(
                    set = True,
                    infinite = True,
                    number = 56, ),
                signal = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal(
                    id = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    name = '', )
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode(self):
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_diag_resp import V0041OpenapiDiagResp


class TestV0041OpenapiDiagResp(unittest.TestCase):
    """V0041OpenapiDiagResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiDiagResp:
        """Test V0041OpenapiDiagResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiDiagResp`
        """
        model = V0041OpenapiDiagResp()
        if include_optional:
            return V0041OpenapiDiagResp(
                statistics = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics.v0_0_41_openapi_diag_resp_statistics(
                    parts_packed = 56,
                    req_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_req_time.v0_0_41_openapi_diag_resp_statistics_req_time(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    req_time_start = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_req_time_start.v0_0_41_openapi_diag_resp_statistics_req_time_start(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    server_thread_count = 56,
                    agent_queue_size = 56,
                    agent_count = 56,
                    agent_thread_count = 56,
                    dbd_agent_queue_size = 56,
                    gettimeofday_latency = 56,
                    schedule_cycle_max = 56,
                    schedule_cycle_last = 56,
                    schedule_cycle_sum = 56,
                    schedule_cycle_total = 56,
                    schedule_cycle_mean = 56,
                    schedule_cycle_mean_depth = 56,
                    schedule_cycle_per_minute = 56,
                    schedule_cycle_depth = 56,
                    schedule_exit = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_schedule_exit.v0_0_41_openapi_diag_resp_statistics_schedule_exit(
                        end_job_queue = 56,
                        default_queue_depth = 56,
                        max_job_start = 56,
                        max_rpc_cnt = 56,
                        max_sched_time = 56,
                        licenses = 56, ),
                    schedule_queue_length = 56,
                    jobs_submitted = 56,
                    jobs_started = 56,
                    jobs_completed = 56,
                    jobs_canceled = 56,
                    jobs_failed = 56,
                    jobs_pending = 56,
                    jobs_running = 56,
                    job_states_ts = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_job_states_ts.v0_0_41_openapi_diag_resp_statistics_job_states_ts(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    bf_backfilled_jobs = 56,
                    bf_last_backfilled_jobs = 56,
                    bf_backfilled_het_jobs = 56,
                    bf_cycle_counter = 56,
                    bf_cycle_mean = 56,
                    bf_depth_mean = 56,
                    bf_depth_mean_try = 56,
                    bf_cycle_sum = 56,
                    bf_cycle_last = 56,
                    bf_cycle_max = 56,
                    bf_exit = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_bf_exit.v0_0_41_openapi_diag_resp_statistics_bf_exit(
                        end_job_queue = 56,
                        bf_max_job_start = 56,
                        bf_max_job_test = 56,
                        bf_max_time = 56,
                        bf_node_space_size = 56,
                        state_changed = 56, ),
                    bf_last_depth = 56,
                    bf_last_depth_try = 56,
                    bf_depth_sum = 56,
                    bf_depth_try_sum = 56,
                    bf_queue_len = 56,
                    bf_queue_len_mean = 56,
                    bf_queue_len_sum = 56,
                    bf_table_size = 56,
                    bf_table_size_sum = 56,
                    bf_table_size_mean = 56,
                    bf_when_last_cycle = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_bf_when_last_cycle.v0_0_41_openapi_diag_resp_statistics_bf_when_last_cycle(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    bf_active = True,
                    rpcs_by_message_type = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner(
                            type_id = 56,
                            message_type = '',
                            count = 56,
                            queued = 56,
                            dropped = 56,
                            cycle_last = 56,
                            cycle_max = 56,
                            total_time = 56,
                            average_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    rpcs_by_user = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_user_inner.v0_0_41_openapi_diag_resp_statistics_rpcs_by_user_inner(
                            user_id = 56,
                            user = '',
                            count = 56,
                            total_time = 56,
                            average_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    pending_rpcs = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_inner.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_inner(
                            type_id = 56,
                            message_type = '',
                            count = 56, )
                        ],
                    pending_rpcs_by_hostlist = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_by_hostlist_inner.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_by_hostlist_inner(
                            type_id = 56,
                            message_type = '',
                            count = [
                                ''
                                ], )
                        ], ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiDiagResp(
                statistics = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics.v0_0_41_openapi_diag_resp_statistics(
                    parts_packed = 56,
                    req_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_req_time.v0_0_41_openapi_diag_resp_statistics_req_time(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    req_time_start = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_req_time_start.v0_0_41_openapi_diag_resp_statistics_req_time_start(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    server_thread_count = 56,
                    agent_queue_size = 56,
                    agent_count = 56,
                    agent_thread_count = 56,
                    dbd_agent_queue_size = 56,
                    gettimeofday_latency = 56,
                    schedule_cycle_max = 56,
                    schedule_cycle_last = 56,
                    schedule_cycle_sum = 56,
                    schedule_cycle_total = 56,
                    schedule_cycle_mean = 56,
                    schedule_cycle_mean_depth = 56,
                    schedule_cycle_per_minute = 56,
                    schedule_cycle_depth = 56,
                    schedule_exit = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_schedule_exit.v0_0_41_openapi_diag_resp_statistics_schedule_exit(
                        end_job_queue = 56,
                        default_queue_depth = 56,
                        max_job_start = 56,
                        max_rpc_cnt = 56,
                        max_sched_time = 56,
                        licenses = 56, ),
                    schedule_queue_length = 56,
                    jobs_submitted = 56,
                    jobs_started = 56,
                    jobs_completed = 56,
                    jobs_canceled = 56,
                    jobs_failed = 56,
                    jobs_pending = 56,
                    jobs_running = 56,
                    job_states_ts = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_job_states_ts.v0_0_41_openapi_diag_resp_statistics_job_states_ts(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    bf_backfilled_jobs = 56,
                    bf_last_backfilled_jobs = 56,
                    bf_backfilled_het_jobs = 56,
                    bf_cycle_counter = 56,
                    bf_cycle_mean = 56,
                    bf_depth_mean = 56,
                    bf_depth_mean_try = 56,
                    bf_cycle_sum = 56,
                    bf_cycle_last = 56,
                    bf_cycle_max = 56,
                    bf_exit = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_bf_exit.v0_0_41_openapi_diag_resp_statistics_bf_exit(
                        end_job_queue = 56,
                        bf_max_job_start = 56,
                        bf_max_job_test = 56,
                        bf_max_time = 56,
                        bf_node_space_size = 56,
                        state_changed = 56, ),
                    bf_last_depth = 56,
                    bf_last_depth_try = 56,
                    bf_depth_sum = 56,
                    bf_depth_try_sum = 56,
                    bf_queue_len = 56,
                    bf_queue_len_mean = 56,
                    bf_queue_len_sum = 56,
                    bf_table_size = 56,
                    bf_table_size_sum = 56,
                    bf_table_size_mean = 56,
                    bf_when_last_cycle = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_bf_when_last_cycle.v0_0_41_openapi_diag_resp_statistics_bf_when_last_cycle(
                        set = True,
                        infinite = True,
                        number = 56, ),
                    bf_active = True,
                    rpcs_by_message_type = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner(
                            type_id = 56,
                            message_type = '',
                            count = 56,
                            queued = 56,
                            dropped = 56,
                            cycle_last = 56,
                            cycle_max = 56,
                            total_time = 56,
                            average_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    rpcs_by_user = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_user_inner.v0_0_41_openapi_diag_resp_statistics_rpcs_by_user_inner(
                            user_id = 56,
                            user = '',
                            count = 56,
                            total_time = 56,
                            average_time = slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time.v0_0_41_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time(
                                set = True,
                                infinite = True,
                                number = 56, ), )
                        ],
                    pending_rpcs = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_inner.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_inner(
                            type_id = 56,
                            message_type = '',
                            count = 56, )
                        ],
                    pending_rpcs_by_hostlist = [
                        slurmrestpy.models.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_by_hostlist_inner.v0_0_41_openapi_diag_resp_statistics_pending_rpcs_by_hostlist_inner(
                            type_id = 56,
                            message_type = '',
                            count = [
                                ''
                                ], )
                        ], ),
        )
        """

    def testV0041OpenapiDiagResp(self):
        """Test V0041OpenapiDiagResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0042_assoc_shares_obj_wrap_fairshare import (
    V0042AssocSharesObjWrapFairshare,
)
from slurmrestpy.models.v0042_assoc_shares_obj_wrap_tres import (
    V0042AssocSharesObjWrapTres,
)
from slurmrestpy.models.v0042_float64_no_val_struct import V0042Float64NoValStruct
from slurmrestpy.models.v0042_uint32_no_val_struct import V0042Uint32NoValStruct


class V0042AssocSharesObjWrap(BaseModel):
    """
    V0042AssocSharesObjWrap
    """  # noqa: E501

    id: Optional[StrictInt] = Field(default=None, description="Association ID")
    cluster: Optional[StrictStr] = Field(default=None, description="Cluster name")
    name: Optional[StrictStr] = Field(default=None, description="Share name")
    parent: Optional[StrictStr] = Field(default=None, description="Parent name")
    partition: Optional[StrictStr] = Field(default=None, description="Partition name")
    shares_normalized: Optional[V0042Float64NoValStruct] = None
    shares: Optional[V0042Uint32NoValStruct] = None
    tres: Optional[V0042AssocSharesObjWrapTres] = None
    effective_usage: Optional[V0042Float64NoValStruct] = None
    usage_normalized: Optional[V0042Float64NoValStruct] = None
    usage: Optional[StrictInt] = Field(
        default=None, description="Measure of tresbillableunits usage"
    )
    fairshare: Optional[V0042AssocSharesObjWrapFairshare] = None
    type: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = [
        "id",
        "cluster",
        "name",
        "parent",
        "partition",
        "shares_normalized",
        "shares",
        "tres",
        "effective_usage",
        "usage_normalized",
        "usage",
        "fairshare",
        "type",
    ]

    @field_validator("type")
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(["USER", "ASSOCIATION"]):
                raise ValueError(
                    "each list item must be one of ('USER', 'ASSOCIATION')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042AssocSharesObjWrap from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of shares_normalized
        if self.shares_normalized:
            _dict["shares_normalized"] = self.shares_normalized.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shares
        if self.shares:
            _dict["shares"] = self.shares.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tres
        if self.tres:
            _dict["tres"] = self.tres.to_dict()
        # override the default output from pydantic by calling `to_dict()` of effective_usage
        if self.effective_usage:
            _dict["effective_usage"] = self.effective_usage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of usage_normalized
        if self.usage_normalized:
            _dict["usage_normalized"] = self.usage_normalized.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fairshare
        if self.fairshare:
            _dict["fairshare"] = self.fairshare.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042AssocSharesObjWrap from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "cluster": obj.get("cluster"),
                "name": obj.get("name"),
                "parent": obj.get("parent"),
                "partition": obj.get("partition"),
                "shares_normalized": V0042Float64NoValStruct.from_dict(
                    obj["shares_normalized"]
                )
                if obj.get("shares_normalized") is not None
                else None,
                "shares": V0042Uint32NoValStruct.from_dict(obj["shares"])
                if obj.get("shares") is not None
                else None,
                "tres": V0042AssocSharesObjWrapTres.from_dict(obj["tres"])
                if obj.get("tres") is not None
                else None,
                "effective_usage": V0042Float64NoValStruct.from_dict(
                    obj["effective_usage"]
                )
                if obj.get("effective_usage") is not None
                else None,
                "usage_normalized": V0042Float64NoValStruct.from_dict(
                    obj["usage_normalized"]
                )
                if obj.get("usage_normalized") is not None
                else None,
                "usage": obj.get("usage"),
                "fairshare": V0042AssocSharesObjWrapFairshare.from_dict(
                    obj["fairshare"]
                )
                if obj.get("fairshare") is not None
                else None,
                "type": obj.get("type"),
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0040_process_exit_code_verbose import (
    V0040ProcessExitCodeVerbose,
)
from slurmrestpy.models.v0040_step_cpu import V0040StepCPU
from slurmrestpy.models.v0040_step_nodes import V0040StepNodes
from slurmrestpy.models.v0040_step_statistics import V0040StepStatistics
from slurmrestpy.models.v0040_step_step import V0040StepStep
from slurmrestpy.models.v0040_step_time import V0040StepTime
from slurmrestpy.models.v0040_step_tres import V0040StepTres
from slurmrestpy.models.v0042_step_task import V0042StepTask
from slurmrestpy.models.v0042_step_tasks import V0042StepTasks


class V0040Step(BaseModel):
    """
    V0040Step
    """  # noqa: E501

    time: Optional[V0040StepTime] = None
    exit_code: Optional[V0040ProcessExitCodeVerbose] = None
    nodes: Optional[V0040StepNodes] = None
    tasks: Optional[V0042StepTasks] = None
    pid: Optional[StrictStr] = Field(default=None, description="Process ID")
    cpu: Optional[V0040StepCPU] = Field(default=None, alias="CPU")
    kill_request_user: Optional[StrictStr] = Field(
        default=None, description="User ID that requested termination of the step"
    )
    state: Optional[List[StrictStr]] = None
    statistics: Optional[V0040StepStatistics] = None
    step: Optional[V0040StepStep] = None
    task: Optional[V0042StepTask] = None
    tres: Optional[V0040StepTres] = None
    __properties: ClassVar[List[str]] = [
        "time",
        "exit_code",
        "nodes",
        "tasks",
        "pid",
        "CPU",
        "kill_request_user",
        "state",
        "statistics",
        "step",
        "task",
        "tres",
    ]

    @field_validator("state")
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "PENDING",
                    "RUNNING",
                    "SUSPENDED",
                    "COMPLETED",
                    "CANCELLED",
                    "FAILED",
                    "TIMEOUT",
                    "NODE_FAIL",
                    "PREEMPTED",
                    "BOOT_FAIL",
                    "DEADLINE",
                    "OUT_OF_MEMORY",
                    "LAUNCH_FAILED",
                    "REQUEUED",
                    "REQUEUE_HOLD",
                    "SPECIAL_EXIT",
                    "RESIZING",
                    "CONFIGURING",
                    "COMPLETING",
                    "STOPPED",
                    "RECONFIG_FAIL",
                    "POWER_UP_NODE",
                    "REVOKED",
                    "REQUEUE_FED",
                    "RESV_DEL_HOLD",
                    "SIGNALING",
                    "STAGE_OUT",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('PENDING', 'RUNNING', 'SUSPENDED', 'COMPLETED', 'CANCELLED', 'FAILED', 'TIMEOUT', 'NODE_FAIL', 'PREEMPTED', 'BOOT_FAIL', 'DEADLINE', 'OUT_OF_MEMORY', 'LAUNCH_FAILED', 'REQUEUED', 'REQUEUE_HOLD', 'SPECIAL_EXIT', 'RESIZING', 'CONFIGURING', 'COMPLETING', 'STOPPED', 'RECONFIG_FAIL', 'POWER_UP_NODE', 'REVOKED', 'REQUEUE_FED', 'RESV_DEL_HOLD', 'SIGNALING', 'STAGE_OUT')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0040Step from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of time
        if self.time:
            _dict["time"] = self.time.to_dict()
        # override the default output from pydantic by calling `to_dict()` of exit_code
        if self.exit_code:
            _dict["exit_code"] = self.exit_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nodes
        if self.nodes:
            _dict["nodes"] = self.nodes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tasks
        if self.tasks:
            _dict["tasks"] = self.tasks.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cpu
        if self.cpu:
            _dict["CPU"] = self.cpu.to_dict()
        # override the default output from pydantic by calling `to_dict()` of statistics
        if self.statistics:
            _dict["statistics"] = self.statistics.to_dict()
        # override the default output from pydantic by calling `to_dict()` of step
        if self.step:
            _dict["step"] = self.step.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task
        if self.task:
            _dict["task"] = self.task.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tres
        if self.tres:
            _dict["tres"] = self.tres.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0040Step from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "time": V0040StepTime.from_dict(obj["time"])
                if obj.get("time") is not None
                else None,
                "exit_code": V0040ProcessExitCodeVerbose.from_dict(obj["exit_code"])
                if obj.get("exit_code") is not None
                else None,
                "nodes": V0040StepNodes.from_dict(obj["nodes"])
                if obj.get("nodes") is not None
                else None,
                "tasks": V0042StepTasks.from_dict(obj["tasks"])
                if obj.get("tasks") is not None
                else None,
                "pid": obj.get("pid"),
                "CPU": V0040StepCPU.from_dict(obj["CPU"])
                if obj.get("CPU") is not None
                else None,
                "kill_request_user": obj.get("kill_request_user"),
                "state": obj.get("state"),
                "statistics": V0040StepStatistics.from_dict(obj["statistics"])
                if obj.get("statistics") is not None
                else None,
                "step": V0040StepStep.from_dict(obj["step"])
                if obj.get("step") is not None
                else None,
                "task": V0042StepTask.from_dict(obj["task"])
                if obj.get("task") is not None
                else None,
                "tres": V0040StepTres.from_dict(obj["tres"])
                if obj.get("tres") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field
from typing_extensions import Self

from slurmrestpy.models.v0042_uint64_no_val_struct import V0042Uint64NoValStruct


class V0042JobDescMsgRlimits(BaseModel):
    """
    V0042JobDescMsgRlimits
    """  # noqa: E501

    cpu: Optional[V0042Uint64NoValStruct] = None
    fsize: Optional[V0042Uint64NoValStruct] = None
    data: Optional[V0042Uint64NoValStruct] = None
    stack: Optional[V0042Uint64NoValStruct] = None
    core: Optional[V0042Uint64NoValStruct] = None
    rss: Optional[V0042Uint64NoValStruct] = None
    nproc: Optional[V0042Uint64NoValStruct] = None
    nofile: Optional[V0042Uint64NoValStruct] = None
    memlock: Optional[V0042Uint64NoValStruct] = None
    var_as: Optional[V0042Uint64NoValStruct] = Field(default=None, alias="as")
    __properties: ClassVar[List[str]] = [
        "cpu",
        "fsize",
        "data",
        "stack",
        "core",
        "rss",
        "nproc",
        "nofile",
        "memlock",
        "as",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042JobDescMsgRlimits from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of cpu
        if self.cpu:
            _dict["cpu"] = self.cpu.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fsize
        if self.fsize:
            _dict["fsize"] = self.fsize.to_dict()
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict["data"] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of stack
        if self.stack:
            _dict["stack"] = self.stack.to_dict()
        # override the default output from pydantic by calling `to_dict()` of core
        if self.core:
            _dict["core"] = self.core.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rss
        if self.rss:
            _dict["rss"] = self.rss.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nproc
        if self.nproc:
            _dict["nproc"] = self.nproc.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nofile
        if self.nofile:
            _dict["nofile"] = self.nofile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of memlock
        if self.memlock:
            _dict["memlock"] = self.memlock.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_as
        if self.var_as:
            _dict["as"] = self.var_as.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042JobDescMsgRlimits from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "cpu": V0042Uint64NoValStruct.from_dict(obj["cpu"])
                if obj.get("cpu") is not None
                else None,
                "fsize": V0042Uint64NoValStruct.from_dict(obj["fsize"])
                if obj.get("fsize") is not None
                else None,
                "data": V0042Uint64NoValStruct.from_dict(obj["data"])
                if obj.get("data") is not None
                else None,
                "stack": V0042Uint64NoValStruct.from_dict(obj["stack"])
                if obj.get("stack") is not None
                else None,
                "core": V0042Uint64NoValStruct.from_dict(obj["core"])
                if obj.get("core") is not None
                else None,
                "rss": V0042Uint64NoValStruct.from_dict(obj["rss"])
                if obj.get("rss") is not None
                else None,
                "nproc": V0042Uint64NoValStruct.from_dict(obj["nproc"])
                if obj.get("nproc") is not None
                else None,
                "nofile": V0042Uint64NoValStruct.from_dict(obj["nofile"])
                if obj.get("nofile") is not None
                else None,
                "memlock": V0042Uint64NoValStruct.from_dict(obj["memlock"])
                if obj.get("memlock") is not None
                else None,
                "as": V0042Uint64NoValStruct.from_dict(obj["as"])
                if obj.get("as") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner,
)


class TestV0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner(
    unittest.TestCase
):
    """V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner:
        """Test V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner`
        """
        model = V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner()
        if include_optional:
            return V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner(
                allocated = slurmrestpy.models.v0_0_40_accounting_allocated.v0_0_40_accounting_allocated(
                    seconds = 56, ),
                id = 56,
                start = 56,
                tres = slurmrestpy.models.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_tres.v0_0_41_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_TRES(
                    type = '',
                    name = '',
                    id = 56,
                    count = 56, )
            )
        else:
            return V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner(
        )
        """

    def testV0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner(self):
        """Test V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0040_openapi_slurmdbd_qos_resp import (
    V0040OpenapiSlurmdbdQosResp,
)


class TestV0040OpenapiSlurmdbdQosResp(unittest.TestCase):
    """V0040OpenapiSlurmdbdQosResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0040OpenapiSlurmdbdQosResp:
        """Test V0040OpenapiSlurmdbdQosResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0040OpenapiSlurmdbdQosResp`
        """
        model = V0040OpenapiSlurmdbdQosResp()
        if include_optional:
            return V0040OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0/0/40_qos.v0.0.40_qos(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_40_qos_limits.v0_0_40_qos_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_40_qos_limits_max.v0_0_40_qos_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_40_qos_limits_max_active_jobs.v0_0_40_qos_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_40_qos_limits_max_tres.v0_0_40_qos_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_40_qos_limits_max_tres_minutes.v0_0_40_qos_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_40_qos_limits_max_tres_minutes_per.v0_0_40_qos_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = ,
                                            account = ,
                                            user = , ), ),
                                    per = slurmrestpy.models.v0_0_40_qos_limits_max_tres_per.v0_0_40_qos_limits_max_tres_per(
                                        node = , ), ),
                                wall_clock = slurmrestpy.models.v0_0_40_qos_limits_max_wall_clock.v0_0_40_qos_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_40_qos_limits_max_jobs.v0_0_40_qos_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_40_qos_limits_max_jobs_active_jobs.v0_0_40_qos_limits_max_jobs_active_jobs(), ),
                            factor = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_40_qos_limits_min.v0_0_40_qos_limits_min(
                                priority_threshold = , ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_40_qos_preempt.v0_0_40_qos_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = , ),
                        priority = ,
                        usage_factor = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = , )
                    ],
                meta = slurmrestpy.models.v0/0/40_openapi_meta.v0.0.40_openapi_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0/0/40_openapi_error.v0.0.40_openapi_error(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0/0/40_openapi_warning.v0.0.40_openapi_warning(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0040OpenapiSlurmdbdQosResp(
                qos = [
                    slurmrestpy.models.v0/0/40_qos.v0.0.40_qos(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_40_qos_limits.v0_0_40_qos_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_40_qos_limits_max.v0_0_40_qos_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_40_qos_limits_max_active_jobs.v0_0_40_qos_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0/0/40_uint32_no_val.v0.0.40_uint32_no_val(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                tres = slurmrestpy.models.v0_0_40_qos_limits_max_tres.v0_0_40_qos_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_40_qos_limits_max_tres_minutes.v0_0_40_qos_limits_max_tres_minutes(
                                        per = slurmrestpy.models.v0_0_40_qos_limits_max_tres_minutes_per.v0_0_40_qos_limits_max_tres_minutes_per(
                                            qos = [
                                                slurmrestpy.models.v0/0/40_tres.v0.0.40_tres(
                                                    type = '',
                                                    name = '',
                                                    id = 56, )
                                                ],
                                            job = ,
                                            account = ,
                                            user = , ), ),
                                    per = slurmrestpy.models.v0_0_40_qos_limits_max_tres_per.v0_0_40_qos_limits_max_tres_per(
                                        node = , ), ),
                                wall_clock = slurmrestpy.models.v0_0_40_qos_limits_max_wall_clock.v0_0_40_qos_limits_max_wall_clock(),
                                jobs = slurmrestpy.models.v0_0_40_qos_limits_max_jobs.v0_0_40_qos_limits_max_jobs(),
                                accruing = slurmrestpy.models.v0_0_40_qos_limits_max_jobs_active_jobs.v0_0_40_qos_limits_max_jobs_active_jobs(), ),
                            factor = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_40_qos_limits_min.v0_0_40_qos_limits_min(
                                priority_threshold = , ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_40_qos_preempt.v0_0_40_qos_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = , ),
                        priority = ,
                        usage_factor = slurmrestpy.models.v0/0/40_float64_no_val.v0.0.40_float64_no_val(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = , )
                    ],
        )
        """

    def testV0040OpenapiSlurmdbdQosResp(self):
        """Test V0040OpenapiSlurmdbdQosResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics,
)


class TestV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics(unittest.TestCase):
    """V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics:
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics`
        """
        model = V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics()
        if include_optional:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics(
                cpu = slurmrestpy.models.v0_0_42_step_statistics_cpu.v0_0_42_step_statistics_CPU(
                    actual_frequency = 56, ),
                energy = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy(
                    consumed = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed.v0_0_41_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed(
                        set = True,
                        infinite = True,
                        number = 56, ), )
            )
        else:
            return V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics(
        )
        """

    def testV0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics(self):
        """Test V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
